summaryrefslogtreecommitdiff
path: root/lib/VNDB/DB/Discussions.pm
diff options
context:
space:
mode:
Diffstat (limited to 'lib/VNDB/DB/Discussions.pm')
-rw-r--r--lib/VNDB/DB/Discussions.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/VNDB/DB/Discussions.pm b/lib/VNDB/DB/Discussions.pm
index 35c44f4c..5e371fbc 100644
--- a/lib/VNDB/DB/Discussions.pm
+++ b/lib/VNDB/DB/Discussions.pm
@@ -153,7 +153,7 @@ sub dbThreadCount {
}
# Options: tid, num, what, order, uid, date >, hide, page, results
# what: user thread
sub dbPostGet {
my($self, %o) = @_;
@@ -169,8 +169,8 @@ sub dbPostGet {
'tp.num = ?' => $o{num} ) : (),
$o{uid} ? (
'tp.uid = ?' => $o{uid} ) : (),
- $o{date} ? (
- 'tp.date > ?' => $o{date} ) : (),
+ $o{mindate} ? (
+ 'tp.date > ?' => $o{mindate} ) : (),
$o{hide} ? (
'tp.hidden = FALSE' => 1 ) : (),
$o{hide} && $o{what} =~ /thread/ ? (
@@ -153,7 +153,7 @@ sub dbThreadCount {
}
-# Options: tid, num, what, order, uid, date >, hide, page, results
+# Options: tid, num, what, order, uid, mindate, hide, page, results
# what: user thread
sub dbPostGet {